CHANGE LOG
==========

1.1.2
-----
- ensure INDEXING_ENABLED is also read from env

1.1.1
-----
- enable reading es host from env

1.1.0
-----
- Added name_only parameter for get_repos for a faster api

1.0.0
-----
- v1.0 formal release

0.0.9
-----
- upgrade EG to 1.5.0 - fixes file handle leak

0.0.8
-----
- Added repo status api

0.0.7
-----
- Added the slugify requirement (#20)

0.0.6
-----
- Introduction of webhooks (#12)

0.0.5
-----
- Bump cornice version to cornice==0.18.1

0.0.4
-----
- Allow for updating content via PUT requests (#5)
- Add Dockerfile and docker image (#8)
- Allow for cloning of repositories via POST requests (#9)

0.0.3
-----
- Start of GET API for repository content

0.0.2
-----
- add support for custom es host

0.0.1
-----
- initial release
